@@ -19,7 +19,7 @@
 
 
 #include <kapplication.h>
-#include <kdebug.h>
+#include <QDebug>
 #include <kxerrorhandler.h>
 #include <kkeyserver.h>
 #include "input.h"
@@ -47,7 +47,7 @@ Gesture::Gesture( bool enabled_P, QObject* parent_P )
         , button( 0 )
         , exclude( NULL )
     {
-    kDebug() << enabled_P;
+    qDebug() << enabled_P;
     (void) new DeleteObject( this, parent_P );
     nostroke_timer.setSingleShot( true );
     connect( &nostroke_timer, SIGNAL(timeout()), SLOT(stroke_timeout()));
@@ -64,7 +64,7 @@ Gesture::~Gesture()
 
 void Gesture::enable( bool enabled_P )
     {
-    kDebug() << enabled_P;
+    qDebug() << enabled_P;
     if( _enabled == enabled_P )
         return;
     _enabled = enabled_P;
@@ -85,9 +85,9 @@ void Gesture::set_exclude( Windowdef_list* windows_P )
 
 void Gesture::update_grab()
     {
-    kDebug() << "Enabled:" << _enabled;
-    kDebug() << "Handler:" << handlers.count();
-    kDebug() << "Exclude:" << exclude << " Match? " << (exclude && exclude->match( Window_data( windows_handler->active_window())));
+    qDebug() << "Enabled:" << _enabled;
+    qDebug() << "Handler:" << handlers.count();
+    qDebug() << "Exclude:" << exclude << " Match? " << (exclude && exclude->match( Window_data( windows_handler->active_window())));
 
     if( _enabled && handlers.count() > 0
         && ( exclude == NULL || !exclude->match( Window_data( windows_handler->active_window()))))
@@ -157,7 +157,7 @@ void Gesture::unregister_handler( QObject* receiver_P, const char* slot_P )
 #if 0
 bool Gesture::x11Event( XEvent* ev_P )
     {
-/*      kDebug() << "   ( type = " << ev_P->type << " )" << KeyRelease << " " << KeyPress ;
+/*      qDebug() << "   ( type = " << ev_P->type << " )" << KeyRelease << " " << KeyPress ;
         if( ev_P->type == XKeyPress || ev_P->type == XKeyRelease )
         {
             return voice_handler->x11Event( ev_P );
@@ -165,7 +165,7 @@ bool Gesture::x11Event( XEvent* ev_P )
 
     if( ev_P->type == ButtonPress && ev_P->xbutton.button == button )
         {
-        kDebug() << "GESTURE: mouse press";
+        qDebug() << "GESTURE: mouse press";
         stroke.reset();
         stroke.record( ev_P->xbutton.x, ev_P->xbutton.y );
         nostroke_timer.start( timeout );
@@ -185,7 +185,7 @@ bool Gesture::x11Event( XEvent* ev_P )
         StrokePoints gesture( stroke.processData() );
         if( gesture.isEmpty() )
             {
-            kDebug() << "GESTURE: replay";
+            qDebug() << "GESTURE: replay";
             XAllowEvents( QX11Info::display(), AsyncPointer, CurrentTime );
             XUngrabPointer( QX11Info::display(), CurrentTime );
             mouse_replay( true );
@@ -230,7 +230,7 @@ bool Gesture::x11Event( XEvent* ev_P )
 
 void Gesture::stroke_timeout()
     {
-    kDebug() << "GESTURE: timeout";
+    qDebug() << "GESTURE: timeout";
     XAllowEvents( QX11Info::display(), AsyncPointer, CurrentTime );
     XUngrabPointer( QX11Info::display(), CurrentTime );
     mouse_replay( false );
@@ -252,11 +252,11 @@ void Gesture::mouse_replay( bool release_P )
 
 void Gesture::grab_mouse( bool grab_P )
     {
-    kDebug() << grab_P;
+    qDebug() << grab_P;
 
     if( grab_P )
         {
-        kDebug() << "gesture grab";
+        qDebug() << "gesture grab";
         Q_ASSERT( button != 0 );
         KXErrorHandler handler;
         static int mask[] = { 0, Button1MotionMask, Button2MotionMask, Button3MotionMask,
@@ -281,11 +281,11 @@ void Gesture::grab_mouse( bool grab_P )
                 ButtonPressMask | ButtonReleaseMask | mask[ button ], GrabModeAsync, GrabModeAsync,
                 None, None );
         bool err = handler.error( true );
-        kDebug() << "Gesture grab:" << err;
+        qDebug() << "Gesture grab:" << err;
         }
     else
         {
-        kDebug() << "Gesture ungrab";
+        qDebug() << "Gesture ungrab";
         XUngrabButton( QX11Info::display(), button, AnyModifier, QX11Info::appRootWindow());
         }
     }
